<?php

declare(strict_types=1);

namespace Drupal\eleos_example\EleosWidget;

use Drupal\block_content\Entity\BlockContent;
use Drupal\Component\Utility\Html;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\eleos\WidgetDefinitionInterface;
use Drupal\eleos_example\Form\ExampleForm;

/**
 * Provides the configs for EleosStandardExampleWidget.
 */
class EleosStandardExampleWidget implements WidgetDefinitionInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function elements(BlockContent $block): array {
    $elements = [];

    $elements['description'] = [
      '#type' => 'markup',
      '#markup' => '<p>' . $block->get('field_eleos_description')->value .'...</p>',
    ];

    $elements['primary_button'] = [
      '#type' => 'button',
      '#value' => $this->t('Primary'),
      '#button_type' => 'primary',
    ];

    $elements['secondary_button'] = [
      '#type' => 'button',
      '#value' => $this->t('Secondary'),
      '#button_type' => 'secondary',
      '#attributes' => [
        'onclick' => 'Drupal.behaviors.eleosStandardExampleWidget.customCallback("Click on secondary!");',
      ],
    ];

    $id = Html::getUniqueId('ajax-button');
    $elements['ajax_button'] = [
      '#type' => 'link',
      '#url' => Url::fromRoute('eleos_example.ajax_main', [], [
        'query' => [
          'element' => $id,
          'value' => 987,
        ],
      ]),
      '#title' => $this->t('Ajax action'),
      '#button_type' => 'secondary',
      '#attributes' => [
        'id' => $id,
        'class' => [
          'button',
          'use-ajax',
        ],
      ],
    ];

    $elements['external_form'] = \Drupal::formBuilder()->getForm(ExampleForm::class);

    $people = $block->get('field_eleos_people')->getValue() ?? [];
    $elements['people_list'] = [
      '#type' => 'container',
    ];
    foreach ($people as $person) {
      $id = Html::getUniqueId('people-btn');
      $element = [
        '#type' => 'link',
        '#url' => Url::fromRoute('eleos_example.ajax_main', [], [
          'query' => [
            'element' => $id,
            'value' => $person['value'],
          ],
        ]),
        '#title' => $person['value'],
        '#button_type' => 'secondary',
        '#attributes' => [
          'class' => [
            'button',
            'use-ajax',
          ],
        ],
      ];

      $wrapper = [
        '#type' => 'container',
        '#attributes' => [
          'id' => $id,
        ],
      ];

      $wrapper['element'] = $element;

      $elements['people_list']['list'][] = $wrapper;
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function libraries(): array {
    return [
      'core/drupal.ajax',
    ];
  }
}