<?php

declare(strict_types=1);

namespace Drupal\eleos_example\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the 'Example' form.
 */
final class ExampleForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'eleos_example_example_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['wrapper'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Example Form'),
    ];

    $form['wrapper']['number'] = [
      '#type' => 'number',
      '#title' => $this->t('Number'),
      '#required' => TRUE,
    ];

    /**
     * There is no direct way to call "#ajax" handler
     * in a form loaded via FormBuilder::getForm.
     *
     * If some element must support ajax do it directly in
     * a block, there are some examples.
     */
    $form['wrapper']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $number = $form_state->getValue('number');
    $form_state->setRebuild();
    $this->messenger()->addStatus($this->t('Number @num has been submitted.', ['@num' => $number]));
  }

}
