<?php

declare(strict_types=1);

namespace Drupal\eleos;

use Drupal\Component\Utility\Html;
use Drupal\Core\Render\Renderer;

/**
 * Eleos Widget service for supporting Eleos blocks.
 */
class Widget {

  /**
   * Standard block.
   *
   * @var string
   */
  const STANDARD_BLOCK = 'standard';

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected Renderer $renderer;

  /**
   * {@inheritdoc}
   */
  public function __construct(Renderer $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * Preprocesses block content.
   *
   * @param string $submoduleName
   *   The name of the submodule providing the block.
   * @param array $variables
   *   The block variables.
   */
  public function preprocessBlock(string $submoduleName, array &$variables) {
    if (empty($variables['content']['#block_content'])) {
      return;
    }

    /** @var \Drupal\block_content\Entity\BlockContent $block */
    $block = $variables['content']['#block_content'];
    $bundle = $block->bundle();

    if (!str_starts_with($bundle, 'eleos_')) {
      return;
    }

    // Initialize library list if not exists.
    if (!isset($variables['#attached']['library'])) {
      $variables['#attached']['library'] = [];
    }

    // Initialize the widget definition class.
    $widget = str_replace(['_', 'block'], ['-', 'widget'], $bundle);
    $widgetClassName = str_replace('-', '', ucwords($widget, '-'));
    $className = '\Drupal\\' . $submoduleName . '\\EleosWidget\\' . $widgetClassName;
    if (class_exists($className)) {
      $widgetDefinition = new $className();

      $libraries = $widgetDefinition->libraries();
      foreach ($libraries as $library) {
        $variables['#attached']['library'][] = $library;
      }

      $elements = $widgetDefinition->elements($block);
      foreach ($elements as $key => $element) {
        $rendered = $this->renderer->render($element);
        $variables['widget'][$key] = $rendered;
      }
    }

    // Attach the main library.
    $variables['#attached']['library'][] = $submoduleName . '/' . $bundle;

    // Set styles.
    $variables['attributes']['id'] = Html::getUniqueId($widget);
    $variables['attributes']['class'][] = 'eleos-widget';
    $variables['attributes']['class'][] = $widget;
  }

}
